@@ -2,14 +2,13 @@
 sbb_binarize CLI
 """
 
-from click import command, option, argument, version_option
-
+from click import command, option, argument, version_option, types
 from .sbb_binarize import SbbBinarizer
 
 @command()
 @version_option()
 @option('--patches/--no-patches', default=True, help='by enabling this parameter you let the model to see the image in patches.')
-@option('--model-dir', '-m', required=True, help='directory containing models for prediction')
+@option('--model-dir', '-m', type=types.Path(exists=True, file_okay=False), required=True, help='directory containing models for prediction')
 @argument('input_image')
 @argument('output_image')
 def main(patches, model_dir, input_image, output_image):
